@@ -23,7 +23,7 @@ from d2b.utils import prepend
 from d2b.utils import rsync
 from d2b.utils import splitext
 
-__version__ = "1.3.1"
+__version__ = "1.4.0"
 
 
 T = TypeVar("T")
@@ -87,6 +87,16 @@ class D2B:
         # each hook returns a list of files
         self.files = sorted(set(itertools.chain(*collected_files)))
 
+        # give hooks the chance to manipulate/"do things" to the collected files
+        pm.hook.prepare_collected_files(  # type: ignore
+            files=self.files,
+            out_dir=self.out_dir,
+            d2b_dir=self.d2b_dir,
+            config=self.config,
+            options=self.options,
+            d2b=self,
+        )
+
         # load the descriptions
         self.descriptions = [
             Description.from_dict(i, d)
